from janome.tokenizer import Tokenizer
import re
from japana.dictionary import lookup_dic


def word_count(text, kana=False, asc=True, _dict=False):
    t = Tokenizer()
    tokens = t.tokenize(text)
    print("total word count: ", len(tokens))
    kanji = r'[ぁ-ゟ]*[㐀-䶵一-鿋豈-頻][ぁ-ゟ]*'
    letters = r'[ぁ-んァ-ン一-龯]|[㐀-䶵一-鿋豈-頻]'

    words = dict()
    for token in tokens:
        word = dict()
        if words.get(token.base_form) is None and re.match(letters if kana else kanji, token.base_form):
            word["word"] = token.base_form
            word["frequency"] = 1
            words[token.base_form] = word
        elif words.get(token.base_form):
            words[token.base_form]["frequency"] += 1

    print("unique word count: ", len(words))
    words = [v for v in words.values()]
    words = sorted(words, key=lambda k: k['frequency'], reverse=not asc)
    word_list = list()
    for value in words:
        word_dic = dict()
        if _dict:
            try:
                word_dic = lookup_dic(value["word"])
            except:
                pass
        word_dic['word'] = value["word"]
        word_dic['frequency'] = value["frequency"]
        word_list.append(word_dic)
    return word_list




from jamdict import Jamdict
jmd = Jamdict()


def lookup_dic(word):
    word_dic = dict()
    result = jmd.lookup(word)
    result = result.to_json()['entries']
    for entry in result:
        if entry['kanji'][0]['text'] == word:
            word_dic['word'] = entry['kanji'][0]['text']
            word_dic['pronunciation'] = entry['kana'][0]['text']
            word_dic['meaning'] = ""
            for j, meaning in enumerate(entry['senses'], start=1):
                if j >= 3:
                    break
                word_dic['meaning'] += str(j) + ". "
                for i, one_sense in enumerate(meaning['SenseGloss'], start=1):
                    if i >= 5:
                        break
                    word_dic['meaning'] += one_sense['text']
                    if i != len(meaning['SenseGloss']) and i != 5:
                        word_dic['meaning'] += "; "
                if j != len(entry['senses']) and j != 3:
                    word_dic['meaning'] += "<br>"
            return word_dic
    return {"word": word}




import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()


requirements = [
'chirptext==0.1a18',
'jamdict==0.1a4',
'Janome==0.3.9',
'lxml==4.3.4',
'mecab-python3==0.996.2',
'puchikarui==0.1a2',
'style==1.1.0',
'update==0.0.1',
]


setuptools.setup(
    name='japana',
    version='0.4',
    author="reem-codes | Reem Ali Alghamdi",
    author_email="reem.brain@gmail.com",
    description="Japanese text analysis",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/reem-codes/japana",
    packages=['japana'],
    license='MIT',
    install_requires=requirements,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



import re
from collections import OrderedDict

hiragana_full = r'[ぁ-ゟ]'
katakana_full = r'[゠-ヿ]'
kanji = r'[㐀-䶵一-鿋豈-頻]'
radicals = r'[⺀-⿕]'
katakana_half_width = r'[｟-ﾟ]'
alphanum_full = r'[！-～]'
symbols_punct = r'[、-〿]'
misc_symbols = r'[ㇰ-ㇿ㈠-㉃㊀-㋾㌀-㍿]'
ascii_char = r'[ -~]'


def extract_unicode_block(unicode_block, string):
    ''' extracts and returns all texts from a unicode block from string argument.
        Note that you must use the unicode blocks defined above, or patterns of similar form '''
    return re.findall( unicode_block, string)


def remove_unicode_block(unicode_block, string):
    ''' removes all chaacters from a unicode block and returns all remaining texts from string argument.
        Note that you must use the unicode blocks defined above, or patterns of similar form '''
    return re.sub(unicode_block, '', string)


def remove_duplicate(str1):
    return "".join(OrderedDict.fromkeys(str1))


def list_kanji(str):
    f = open(str, "r")
    vocab = f.read()
    f.close()
    vocab = ''.join(extract_unicode_block(kanji, vocab))
    kanji_list = remove_duplicate(vocab)
    # print(len(kanji_list), kanji_list)
    print("unique kanji count: ", len(kanji_list))
    return kanji_list
#
#
# word = list_kanji("word.csv")
# jlpt = list_kanji("jlpt.csv")
# n3 = list_kanji("jlpt3.csv")
# done = list_kanji("exportcsv.csv")
# kanji_list = word + jlpt + done + n3
# kanji_list = remove_duplicate(kanji_list)
# print(len(kanji_list), kanji_list)
#
# print("kanji left in kanjidamage: ")
#
# f = open("kanjidamage.csv", "r")
# kd = f.read()
# f.close()
# new_kanji = list(set(kd)^set(kanji_list))
# new_kanji = ''.join(new_kanji)
# print(len(new_kanji), new_kanji)
# new_kanji = ''.join(extract_unicode_block(kanji, new_kanji))
# print(len(new_kanji), new_kanji)
#
# old = open("KanjiDamage Reordered.txt", "r")
# new_file = open("new_kanjiDamage.txt", "a")
# new_file.truncate(0)
# for line in old:
#     word = line.split("\t", 2)[1]
#     if word in new_kanji and re.match(kanji, word):
#         new_file.write(line)
# new_file.close()
# old.close()
#

#
# new = ''
# doc = open("new_kanjiDamage.txt", 'r')
# for line in doc:
#     new = new + line.split("\t", 2)[1]
#
# print(len(new), new)
#
# now = list_kanji("now.csv")
# exclude = list(set(new)^set(now))
# exclude = ''.join(exclude)
# print(len(exclude), exclude)